@@ -327,7 +327,7 @@ def PySconsSetup(env=None, args=ARGUMENTS, tools=['default', PYTOOL()]):
         shutil.mv(force, out)
         env.Exit(0)
 
-    env.Command(ship, sources + [exe], "tar cjf $TARGET $SOURCES")
+    env.Command(ship, sources + [exe, myname], "tar cjf $TARGET $SOURCES")
     env.Default(targets)
     SIGNATURES = os.path.join(basename, ".sconsign.dblite")
     env.Command(out, targets, "tar cjf $TARGET $SOURCES")
